enum SqlTokenKind: string

Lexical categories needed for lossless SQL structure inspection.

Cases

case Word = 'word'
case QuotedIdentifier = 'quoted_identifier'
case String = 'string'
case Number = 'number'
case Parameter = 'parameter'
case Symbol = 'symbol'
case Comment = 'comment'
case Whitespace = 'whitespace'

Test cases 44

Test cases that cover or call this symbol, from the coverage report and from the analyzed test sources.

Dedicated tests 1
Other tests reaching this symbol 43

Relations

Constant reads 21
Type declarations 3