enum TransactionOperation: string

What a transaction statement does to the shadow.

Cases

case Begin = 'begin'
case Commit = 'commit'
case Rollback = 'rollback'
case Savepoint = 'savepoint'
case RollbackTo = 'rollback_to'
case Release = 'release'

Test cases 1

Test cases that cover or call this symbol, from the coverage report and from the analyzed test sources.

Dedicated tests 1

Relations

Constant reads 12
Type declarations 1